=================
Generation module
=================

Functions that generates the underlying connectivity of graphs, as well
as the connection properties (weight/strength and delay).


Content
=======

.. autosummary::

    nngt.generation.all_to_all
    nngt.generation.connect_neural_groups
    nngt.generation.connect_neural_types
    nngt.generation.connect_nodes
    nngt.generation.distance_rule
    nngt.generation.erdos_renyi
    nngt.generation.fixed_degree
    nngt.generation.gaussian_degree
    nngt.generation.newman_watts
    nngt.generation.price_scale_free
    nngt.generation.random_scale_free


.. automodule:: nngt.generation
